# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`graphdb`](#graphdb): # This class is able to install or remove graphdb distribution on a node. It manages the status of the related service.
* [`graphdb::install`](#graphdb--install): Perform the actual download of distribution archive and installations. Not meant to be used directly.
* [`graphdb::tool_links`](#graphdb--tool_links): Adds GraphDB tool to system path. Not meant to be used directly.

### Defined types

* [`graphdb::data`](#graphdb--data): This define allows you to import data from given source(incl. zip archive)
* [`graphdb::ee::master::repository`](#graphdb--ee--master--repository): This define is able to manage GraphDB repository
* [`graphdb::ee::worker::repository`](#graphdb--ee--worker--repository): This define is able to manage GraphDB repository
* [`graphdb::instance`](#graphdb--instance): This define allows you to create or remove an graphdb instance
* [`graphdb::plugin`](#graphdb--plugin): This define allows you to install GraphDB plugin from given source
* [`graphdb::se::repository`](#graphdb--se--repository): This define is able to manage GraphDB repository
* [`graphdb::service`](#graphdb--service): Based on parameters passed defines systemd service

### Resource types

* [`graphdb_data`](#graphdb_data): Loads data into GraphDB
* [`graphdb_link`](#graphdb_link): Creates link between master and worker
* [`graphdb_repository`](#graphdb_repository): Creates GraphDB repository
* [`graphdb_update`](#graphdb_update): Executes update query GraphDB
* [`graphdb_validator`](#graphdb_validator): Checks whether GraphDB instance is running

### Functions

* [`generate_java_opts_string`](#generate_java_opts_string): This function java opts string from given array.

### Data types

* [`Graphdb::Ensure`](#Graphdb--Ensure): Validate the value of the ensure parameter for a install
* [`Graphdb::Status`](#Graphdb--Status): Validate the value of the status parameter for a install

## Classes

### <a name="graphdb"></a>`graphdb`

# This class is able to install or remove graphdb distribution on a node. It manages the status of the related service.

#### Parameters

The following parameters are available in the `graphdb` class:

* [`ensure`](#-graphdb--ensure)
* [`version`](#-graphdb--version)
* [`edition`](#-graphdb--edition)
* [`status`](#-graphdb--status)
* [`tmp_dir`](#-graphdb--tmp_dir)
* [`data_dir`](#-graphdb--data_dir)
* [`log_dir`](#-graphdb--log_dir)
* [`pid_dir`](#-graphdb--pid_dir)
* [`install_dir`](#-graphdb--install_dir)
* [`import_dir`](#-graphdb--import_dir)
* [`manage_graphdb_user`](#-graphdb--manage_graphdb_user)
* [`graphdb_user`](#-graphdb--graphdb_user)
* [`graphdb_group`](#-graphdb--graphdb_group)
* [`java_home`](#-graphdb--java_home)
* [`restart_on_change`](#-graphdb--restart_on_change)
* [`purge_data_dir`](#-graphdb--purge_data_dir)
* [`archive_dl_timeout`](#-graphdb--archive_dl_timeout)
* [`graphdb_download_user`](#-graphdb--graphdb_download_user)
* [`graphdb_download_password`](#-graphdb--graphdb_download_password)
* [`graphdb_download_url`](#-graphdb--graphdb_download_url)

##### <a name="-graphdb--ensure"></a>`ensure`

Data type: `Graphdb::Ensure`

String. Controls if the managed resources shall be <tt>present</tt> or
<tt>absent</tt>. If set to <tt>absent</tt>:
* The managed distribution is being uninstalled.
* Any traces of installation will be purged as good as possible. This may
  include existing configuration files. The exact behavior is provider
  dependent. Q.v.:
  * Puppet type reference: {package, "purgeable"}[http://j.mp/xbxmNP]
  * {Puppet's package provider source code}[http://j.mp/wtVCaL]
* System modifications (if any) will be reverted as good as possible
  (e.g. removal of created users, services, changed log settings, ...).
* This is thus destructive and should be used with care.
Defaults to <tt>present</tt>.

Default value: `'present'`

##### <a name="-graphdb--version"></a>`version`

Data type: `String`

String. GraphDB version to install

Default value: `undef`

##### <a name="-graphdb--edition"></a>`edition`

Data type: `Optional[String]`

String. GraphDB edition to install

Default value: `undef`

##### <a name="-graphdb--status"></a>`status`

Data type: `Graphdb::Status`

String to define the status of the service. Possible values:
* <tt>enabled</tt>: Service is running and will be started at boot time.
* <tt>disabled</tt>: Service is stopped and will not be started at boot
  time.
* <tt>running</tt>: Service is running but will not be started at boot time.
  You can use this to start a service on the first Puppet run instead of
  the system startup.
* <tt>unmanaged</tt>: Service will not be started at boot time and Puppet
  does not care whether the service is running or not. For example, this may
  be useful if a cluster management software is used to decide when to start
  the service plus assuring it is running on the desired node.
Defaults to <tt>enabled</tt>. The singular form ("service") is used for the
sake of convenience. Of course, the defined status affects all services if
more than one is managed (see <tt>service.pp</tt> to check if this is the
case).

Default value: `'enabled'`

##### <a name="-graphdb--tmp_dir"></a>`tmp_dir`

Data type: `Stdlib::Absolutepath`

String. The location of temporary files that this module will use

Default value: `'/var/tmp/graphdb'`

##### <a name="-graphdb--data_dir"></a>`data_dir`

Data type: `Stdlib::Absolutepath`

String. GraphDB data directory

Default value: `'/var/lib/graphdb'`

##### <a name="-graphdb--log_dir"></a>`log_dir`

Data type: `Stdlib::Absolutepath`

String. GraphDB log directory

Default value: `'/var/log/graphdb'`

##### <a name="-graphdb--pid_dir"></a>`pid_dir`

Data type: `Stdlib::Absolutepath`

String. GraphDB pid directory

Default value: `'/var/run/graphdb'`

##### <a name="-graphdb--install_dir"></a>`install_dir`

Data type: `Stdlib::Absolutepath`

String. GraphDB distribution location

Default value: `'/opt/graphdb'`

##### <a name="-graphdb--import_dir"></a>`import_dir`

Data type: `Stdlib::Absolutepath`

String. GraphDB import location

Default value: `"${install_dir}/import"`

##### <a name="-graphdb--manage_graphdb_user"></a>`manage_graphdb_user`

Data type: `Boolean`

Boolean. Whether this module manages GraphDB user

Default value: `true`

##### <a name="-graphdb--graphdb_user"></a>`graphdb_user`

Data type: `String[1,32]`

String. The group GraphDB should run as. This also sets the file rights

Default value: `'graphdb'`

##### <a name="-graphdb--graphdb_group"></a>`graphdb_group`

Data type: `String[1,32]`

String. The group GraphDB should run as. This also sets the file rights

Default value: `'graphdb'`

##### <a name="-graphdb--java_home"></a>`java_home`

Data type: `Optional[Stdlib::Absolutepath]`

String. The location of java installation

Default value: `undef`

##### <a name="-graphdb--restart_on_change"></a>`restart_on_change`

Data type: `Boolean`

Boolean that determines if the application should be automatically restarted
whenever the configuration change. Enabling this
setting will cause GraphDB to restart whenever there is cause to
re-read configuration files, load new plugins, or start the service using an
updated/changed executable. This may be undesireable in highly available
environments.

Default value: `true`

##### <a name="-graphdb--purge_data_dir"></a>`purge_data_dir`

Data type: `Boolean`

Boolean. Purge data directory on removal

Default value: `false`

##### <a name="-graphdb--archive_dl_timeout"></a>`archive_dl_timeout`

Data type: `Integer`

For http downloads you can set how long the exec resource may take.
default: 600 seconds

Default value: `600`

##### <a name="-graphdb--graphdb_download_user"></a>`graphdb_download_user`

Data type: `Optional[String]`

For http downloads you can set user(basic auth credentials)

Default value: `undef`

##### <a name="-graphdb--graphdb_download_password"></a>`graphdb_download_password`

Data type: `Optional[String]`

For http downloads you can set password(basic auth credentials)

Default value: `undef`

##### <a name="-graphdb--graphdb_download_url"></a>`graphdb_download_url`

Data type: `String`

Url to the archive to download.
This can be a http or https resource for remote packages
puppet:// resource or file:/ for local packages

Default value: `'http://maven.ontotext.com/content/groups/all-onto/com/ontotext/graphdb'`

### <a name="graphdb--install"></a>`graphdb::install`

Perform the actual download of distribution archive and installations. Not meant to be used directly.

### <a name="graphdb--tool_links"></a>`graphdb::tool_links`

Adds GraphDB tool to system path. Not meant to be used directly.

## Defined types

### <a name="graphdb--data"></a>`graphdb::data`

default: null

#### Parameters

The following parameters are available in the `graphdb::data` defined type:

* [`endpoint`](#-graphdb--data--endpoint)
* [`repository`](#-graphdb--data--repository)
* [`exists_query`](#-graphdb--data--exists_query)
* [`exists_expected_response`](#-graphdb--data--exists_expected_response)
* [`data`](#-graphdb--data--data)
* [`source`](#-graphdb--data--source)
* [`archive`](#-graphdb--data--archive)
* [`data_format`](#-graphdb--data--data_format)
* [`context`](#-graphdb--data--context)
* [`overwrite`](#-graphdb--data--overwrite)
* [`timeout`](#-graphdb--data--timeout)

##### <a name="-graphdb--data--endpoint"></a>`endpoint`

Data type: `String`

GraphDB endpoint.
example: http://localhost:8080

##### <a name="-graphdb--data--repository"></a>`repository`

Data type: `String`

GraphDB repository.

##### <a name="-graphdb--data--exists_query"></a>`exists_query`

Data type: `String`

The ask query to check whether data is already loaded.
You can use the following syntax: ask {?s ?p ?o}

##### <a name="-graphdb--data--exists_expected_response"></a>`exists_expected_response`

Data type: `Boolean`

The expected response from exists_query
default: true

Default value: `true`

##### <a name="-graphdb--data--data"></a>`data`

Data type: `Optional[String]`

The data you want to load into GraphDB repository.
Supported formats:
String: 'data'
Array: ['data#1','data#2']
Array of Hashes: [{'content' => 'data#1', 'context' => 'context_of_data#1', 'format' => 'format_of_data1'},
{'content' => 'data#2', 'context' => 'context_of_data#2', 'format' => 'format_of_data2'}]
Mixed Array: [{'content' => 'data#1', 'context' => 'context_of_data#1', 'format' => 'format_of_data1'}, 'data#2']
note#1: if context for data not provided data_context is used
note#2: if format for data not provided data_format is used

Default value: `undef`

##### <a name="-graphdb--data--source"></a>`source`

Data type: `Optional[String]`

The source of data you want to load into GraphDB repository.
Supported formats:
String: 'path_to_file'
String: 'path_to_directory'
Array: ['path_to_file#1','path_to_file#2']
Array of Hashes: [{'source' => 'path_to_file#1', 'context' => 'context_of_file#1', 'format' => 'format_of_file#1'},
{'source' => 'path_to_file#2', 'context' => 'context_of_file#2', 'format' => 'format_of_file#2'}]
Mixed Array: [{'source' => 'path_to_file#1', 'context' => 'context_of_file#1', 'format' => 'format_of_file#1'},
'path_to_file#2']
note#1: if context for file not provided data_context is used
note#2: if format for file not provided trying to resolve format from file if fails data_format is used

Default value: `undef`

##### <a name="-graphdb--data--archive"></a>`archive`

Data type: `Optional[String]`

Local zip archive that you want to load into GraphDB repository.

Default value: `undef`

##### <a name="-graphdb--data--data_format"></a>`data_format`

Data type: `Optional[String]`

The data format.
example: turtle

Default value: `undef`

##### <a name="-graphdb--data--context"></a>`context`

Data type: `String`

The context you want to load your data into.

Default value: `'null'`

##### <a name="-graphdb--data--overwrite"></a>`overwrite`

Data type: `Boolean`

Wheather to overwrite any existing data.
default: false

Default value: `false`

##### <a name="-graphdb--data--timeout"></a>`timeout`

Data type: `Integer`

The max number of seconds that the loading process should wait before giving up.
default: 200

Default value: `200`

### <a name="graphdb--ee--master--repository"></a>`graphdb::ee::master::repository`

For other properties, please, check: {GraphDB documentation}[http://graphdb.ontotext.com/documentation/enterprise/configuring-a-repository.html?highlight=repository#configuration-parameters]

#### Parameters

The following parameters are available in the `graphdb::ee::master::repository` defined type:

* [`ensure`](#-graphdb--ee--master--repository--ensure)
* [`endpoint`](#-graphdb--ee--master--repository--endpoint)
* [`repository_context`](#-graphdb--ee--master--repository--repository_context)
* [`repository_template`](#-graphdb--ee--master--repository--repository_template)
* [`replication_port`](#-graphdb--ee--master--repository--replication_port)
* [`node_id`](#-graphdb--ee--master--repository--node_id)
* [`timeout`](#-graphdb--ee--master--repository--timeout)
* [`repository_id`](#-graphdb--ee--master--repository--repository_id)
* [`repository_label`](#-graphdb--ee--master--repository--repository_label)

##### <a name="-graphdb--ee--master--repository--ensure"></a>`ensure`

Data type: `Graphdb::Ensure`

Whether the service should exist. Possible values are present and absent.

Default value: `$graphdb::ensure`

##### <a name="-graphdb--ee--master--repository--endpoint"></a>`endpoint`

Data type: `String`

GraphDB endpoint.
example: http://localhost:8080

##### <a name="-graphdb--ee--master--repository--repository_context"></a>`repository_context`

Data type: `String`

The context of the repository.
example: http://ontotext.com

##### <a name="-graphdb--ee--master--repository--repository_template"></a>`repository_template`

Data type: `String`

The template to use for repository creation
example: http://ontotext.com

Default value: `"${module_name}/repository/master.ttl.erb"`

##### <a name="-graphdb--ee--master--repository--replication_port"></a>`replication_port`

Data type: `Integer`

Master replication port used for backups
default: 0, random port used

Default value: `0`

##### <a name="-graphdb--ee--master--repository--node_id"></a>`node_id`

Data type: `String`

Node id of master instance
default: endpoint, same as the master instance endpoint

Default value: `"${endpoint}/repositories/${repository_id}"`

##### <a name="-graphdb--ee--master--repository--timeout"></a>`timeout`

Data type: `Integer`

The max number of seconds that the repository create/delete/check process should wait before giving up.
default: 60

Default value: `60`

##### <a name="-graphdb--ee--master--repository--repository_id"></a>`repository_id`

Data type: `String`

Repository ID

Default value: `$title`

##### <a name="-graphdb--ee--master--repository--repository_label"></a>`repository_label`

Data type: `String`

Repository title

Default value: `'GraphDB EE master repository'`

### <a name="graphdb--ee--worker--repository"></a>`graphdb::ee::worker::repository`

For other properties, please, check: {GraphDB documentation}[http://graphdb.ontotext.com/documentation/enterprise/configuring-a-repository.html?highlight=repository#configuration-parameters]

#### Parameters

The following parameters are available in the `graphdb::ee::worker::repository` defined type:

* [`ensure`](#-graphdb--ee--worker--repository--ensure)
* [`endpoint`](#-graphdb--ee--worker--repository--endpoint)
* [`repository_context`](#-graphdb--ee--worker--repository--repository_context)
* [`repository_template`](#-graphdb--ee--worker--repository--repository_template)
* [`timeout`](#-graphdb--ee--worker--repository--timeout)
* [`repository_id`](#-graphdb--ee--worker--repository--repository_id)
* [`repository_label`](#-graphdb--ee--worker--repository--repository_label)
* [`default_ns`](#-graphdb--ee--worker--repository--default_ns)
* [`entity_index_size`](#-graphdb--ee--worker--repository--entity_index_size)
* [`entity_id_size`](#-graphdb--ee--worker--repository--entity_id_size)
* [`imports`](#-graphdb--ee--worker--repository--imports)
* [`ruleset`](#-graphdb--ee--worker--repository--ruleset)
* [`storage_folder`](#-graphdb--ee--worker--repository--storage_folder)
* [`enable_context_index`](#-graphdb--ee--worker--repository--enable_context_index)
* [`enable_predicate_list`](#-graphdb--ee--worker--repository--enable_predicate_list)
* [`in_memory_literal_properties`](#-graphdb--ee--worker--repository--in_memory_literal_properties)
* [`enable_literal_index`](#-graphdb--ee--worker--repository--enable_literal_index)
* [`check_for_inconsistencies`](#-graphdb--ee--worker--repository--check_for_inconsistencies)
* [`disable_same_as`](#-graphdb--ee--worker--repository--disable_same_as)
* [`transaction_mode`](#-graphdb--ee--worker--repository--transaction_mode)
* [`transaction_isolation`](#-graphdb--ee--worker--repository--transaction_isolation)
* [`query_timeout`](#-graphdb--ee--worker--repository--query_timeout)
* [`query_limit_results`](#-graphdb--ee--worker--repository--query_limit_results)
* [`throw_query_evaluation_exception_on_timeout`](#-graphdb--ee--worker--repository--throw_query_evaluation_exception_on_timeout)
* [`non_interpretable_predicates`](#-graphdb--ee--worker--repository--non_interpretable_predicates)
* [`read_only`](#-graphdb--ee--worker--repository--read_only)

##### <a name="-graphdb--ee--worker--repository--ensure"></a>`ensure`

Data type: `Graphdb::Ensure`

Whether the service should exist. Possible values are present and absent.

Default value: `$graphdb::ensure`

##### <a name="-graphdb--ee--worker--repository--endpoint"></a>`endpoint`

Data type: `String`

GraphDB endpoint.
example: http://localhost:8080

##### <a name="-graphdb--ee--worker--repository--repository_context"></a>`repository_context`

Data type: `String`

The context of the repository.
example: http://ontotext.com

##### <a name="-graphdb--ee--worker--repository--repository_template"></a>`repository_template`

Data type: `String`

The template to use for repository creation
example: http://ontotext.com

Default value: `"${module_name}/repository/worker.ttl.erb"`

##### <a name="-graphdb--ee--worker--repository--timeout"></a>`timeout`

Data type: `Integer`

The max number of seconds that the repository create/delete/check process should wait before giving up.
default: 60

Default value: `60`

##### <a name="-graphdb--ee--worker--repository--repository_id"></a>`repository_id`

Data type: `String`

Repository ID

Default value: `$title`

##### <a name="-graphdb--ee--worker--repository--repository_label"></a>`repository_label`

Data type: `String`

Repository title

Default value: `'GraphDB EE worker repository'`

##### <a name="-graphdb--ee--worker--repository--default_ns"></a>`default_ns`

Data type: `String`

Default namespaces for imports(';' delimited)

Default value: `''`

##### <a name="-graphdb--ee--worker--repository--entity_index_size"></a>`entity_index_size`

Data type: `String`

Entity index size

Default value: `'200000'`

##### <a name="-graphdb--ee--worker--repository--entity_id_size"></a>`entity_id_size`

Data type: `String`

Entity ID bit-size

Default value: `'32'`

##### <a name="-graphdb--ee--worker--repository--imports"></a>`imports`

Data type: `String`

Imported RDF files(';' delimited)

Default value: `''`

##### <a name="-graphdb--ee--worker--repository--ruleset"></a>`ruleset`

Data type: `String`

Rule-set

Default value: `'owl-horst-optimized'`

##### <a name="-graphdb--ee--worker--repository--storage_folder"></a>`storage_folder`

Data type: `String`

Storage folder

Default value: `'storage'`

##### <a name="-graphdb--ee--worker--repository--enable_context_index"></a>`enable_context_index`

Data type: `Boolean`

Use context index

Default value: `false`

##### <a name="-graphdb--ee--worker--repository--enable_predicate_list"></a>`enable_predicate_list`

Data type: `Boolean`

Use predicate indices

Default value: `false`

##### <a name="-graphdb--ee--worker--repository--in_memory_literal_properties"></a>`in_memory_literal_properties`

Data type: `Boolean`

Cache literal language tags

Default value: `false`

##### <a name="-graphdb--ee--worker--repository--enable_literal_index"></a>`enable_literal_index`

Data type: `Boolean`

Enable literal index

Default value: `true`

##### <a name="-graphdb--ee--worker--repository--check_for_inconsistencies"></a>`check_for_inconsistencies`

Data type: `Boolean`

Check for inconsistencies

Default value: `false`

##### <a name="-graphdb--ee--worker--repository--disable_same_as"></a>`disable_same_as`

Data type: `Boolean`

Disable OWL sameAs optimisation

Default value: `false`

##### <a name="-graphdb--ee--worker--repository--transaction_mode"></a>`transaction_mode`

Data type: `String`

Transaction mode

Default value: `'safe'`

##### <a name="-graphdb--ee--worker--repository--transaction_isolation"></a>`transaction_isolation`

Data type: `Boolean`

Transaction isolation

Default value: `true`

##### <a name="-graphdb--ee--worker--repository--query_timeout"></a>`query_timeout`

Data type: `String`

Query time-out (seconds)

Default value: `'0'`

##### <a name="-graphdb--ee--worker--repository--query_limit_results"></a>`query_limit_results`

Data type: `String`

Limit query results

Default value: `'0'`

##### <a name="-graphdb--ee--worker--repository--throw_query_evaluation_exception_on_timeout"></a>`throw_query_evaluation_exception_on_timeout`

Data type: `Boolean`

Throw exception on query time-out

Default value: `false`

##### <a name="-graphdb--ee--worker--repository--non_interpretable_predicates"></a>`non_interpretable_predicates`

Data type: `String`

Non-interpretable predicates

Default value: `'http://www.w3.org/2000/01/rdf-schema#label;http://www.w3.org/1999/02/22-rdf-syntax-ns#type;http://www.ontotext.com/owlim/ces#gazetteerConfig;http://www.ontotext.com/owlim/ces#metadataConfig'`

##### <a name="-graphdb--ee--worker--repository--read_only"></a>`read_only`

Data type: `Boolean`

Read-only

Default value: `false`

### <a name="graphdb--instance"></a>`graphdb::instance`

This define allows you to create or remove an graphdb instance

#### Parameters

The following parameters are available in the `graphdb::instance` defined type:

* [`ensure`](#-graphdb--instance--ensure)
* [`status`](#-graphdb--instance--status)
* [`license`](#-graphdb--instance--license)
* [`http_port`](#-graphdb--instance--http_port)
* [`kill_timeout`](#-graphdb--instance--kill_timeout)
* [`validator_timeout`](#-graphdb--instance--validator_timeout)
* [`validator_test_enabled`](#-graphdb--instance--validator_test_enabled)
* [`heap_size`](#-graphdb--instance--heap_size)
* [`external_url`](#-graphdb--instance--external_url)
* [`logback_config`](#-graphdb--instance--logback_config)
* [`extra_properties`](#-graphdb--instance--extra_properties)
* [`java_opts`](#-graphdb--instance--java_opts)
* [`protocol`](#-graphdb--instance--protocol)
* [`jolokia_access_link`](#-graphdb--instance--jolokia_access_link)

##### <a name="-graphdb--instance--ensure"></a>`ensure`

Data type: `Graphdb::Ensure`

String. Controls if the managed resources shall be <tt>present</tt> or
<tt>absent</tt>. If set to <tt>absent</tt>:
* The managed instance is being uninstalled.
* Any traces of installation will be purged as good as possible. This may
  include existing configuration files. The exact behavior is provider
  dependent. Q.v.:
  * Puppet type reference: {package, "purgeable"}[http://j.mp/xbxmNP]
  * {Puppet's package provider source code}[http://j.mp/wtVCaL]
* System modifications (if any) will be reverted as good as possible
  (e.g. removal of created users, services, changed log settings, ...).
* This is thus destructive and should be used with care.
Defaults to <tt>present</tt>.

Default value: `$graphdb::ensure`

##### <a name="-graphdb--instance--status"></a>`status`

Data type: `Graphdb::Status`

String to define the status of the service. Possible values:
* <tt>enabled</tt>: Service is running and will be started at boot time.
* <tt>disabled</tt>: Service is stopped and will not be started at boot
  time.
* <tt>running</tt>: Service is running but will not be started at boot time.
  You can use this to start a service on the first Puppet run instead of
  the system startup.
* <tt>unmanaged</tt>: Service will not be started at boot time and Puppet
  does not care whether the service is running or not. For example, this may
  be useful if a cluster management software is used to decide when to start
  the service plus assuring it is running on the desired node.
Defaults to <tt>enabled</tt>. The singular form ("service") is used for the
sake of convenience. Of course, the defined status affects all services if
more than one is managed (see <tt>service.pp</tt> to check if this is the
case).

Default value: `$graphdb::status`

##### <a name="-graphdb--instance--license"></a>`license`

Data type: `Optional[String]`

GraphDB license file.

Default value: `undef`

##### <a name="-graphdb--instance--http_port"></a>`http_port`

Data type: `Integer`

The http port at which GraphDB will run.

Default value: `8080`

##### <a name="-graphdb--instance--kill_timeout"></a>`kill_timeout`

Data type: `Integer`

Time before force kill of GraphDB process. Instances with big repositories may
time to flush on shutdown.
default: 180

Default value: `180`

##### <a name="-graphdb--instance--validator_timeout"></a>`validator_timeout`

Data type: `Integer`

Time before GraphDB validator decides that the GraphDB instance is not running

Default value: `60`

##### <a name="-graphdb--instance--validator_test_enabled"></a>`validator_test_enabled`

Data type: `Boolean`

GraphDB validator

Default value: `true`

##### <a name="-graphdb--instance--heap_size"></a>`heap_size`

Data type: `Optional[String]`

GraphDB java heap size given by -Xmx parameter. Note heap_size parameter will also set xms=xmx

Default value: `undef`

##### <a name="-graphdb--instance--external_url"></a>`external_url`

Data type: `Optional[String]`

GraphDB external URL if GraphDB instance is accessed via proxy

Default value: `undef`

##### <a name="-graphdb--instance--logback_config"></a>`logback_config`

Data type: `Optional[String]`

GraphDB logback log configuration

Default value: `undef`

##### <a name="-graphdb--instance--extra_properties"></a>`extra_properties`

Data type: `Hash`

Hash of properties to include in graphdb.properties file
example: {'graphdb.some.property' => 'some.property.value'}

Default value: `{}`

##### <a name="-graphdb--instance--java_opts"></a>`java_opts`

Data type: `Array`

Array of java options to give to GraphDB java process
example: ['-Xmx1g', '-Xms1g']

Default value: `[]`

##### <a name="-graphdb--instance--protocol"></a>`protocol`

Data type: `String`

A string, either 'http' or 'https defining under what protocol to connect to GraphDB'

Default value: `'http'`

##### <a name="-graphdb--instance--jolokia_access_link"></a>`jolokia_access_link`

Data type: `Boolean`

Add jolokia-access.xml link

Default value: `versioncmp($graphdb::ensure, '9.10.0') > -1`

### <a name="graphdb--plugin"></a>`graphdb::plugin`

This define allows you to install GraphDB plugin from given source

#### Parameters

The following parameters are available in the `graphdb::plugin` defined type:

* [`ensure`](#-graphdb--plugin--ensure)
* [`instance`](#-graphdb--plugin--instance)
* [`source`](#-graphdb--plugin--source)

##### <a name="-graphdb--plugin--ensure"></a>`ensure`

Data type: `Graphdb::Ensure`

String. Controls if the managed resources shall be <tt>present</tt> or
<tt>absent</tt>. If set to <tt>absent</tt>:
* The managed plugin is being uninstalled.
* Any traces of installation will be purged as good as possible. This may
  include existing configuration files. The exact behavior is provider
  dependent. Q.v.:
  * Puppet type reference: {package, "purgeable"}[http://j.mp/xbxmNP]
  * {Puppet's package provider source code}[http://j.mp/wtVCaL]
* System modifications (if any) will be reverted as good as possible
  (e.g. removal of created users, services, changed log settings, ...).
* This is thus destructive and should be used with care.
Defaults to <tt>present</tt>.

Default value: `$graphdb::ensure`

##### <a name="-graphdb--plugin--instance"></a>`instance`

Data type: `String`

GraphDB instance to install plugin on.

##### <a name="-graphdb--plugin--source"></a>`source`

Data type: `Optional[String]`

The source of GraphDB plugin.

Default value: `undef`

### <a name="graphdb--se--repository"></a>`graphdb::se::repository`

For other properties, please, check: {GraphDB documentation}[http://graphdb.ontotext.com/documentation/standard/configuring-a-repository.html?highlight=repository#configuration-parameters]

#### Parameters

The following parameters are available in the `graphdb::se::repository` defined type:

* [`ensure`](#-graphdb--se--repository--ensure)
* [`endpoint`](#-graphdb--se--repository--endpoint)
* [`repository_context`](#-graphdb--se--repository--repository_context)
* [`repository_template`](#-graphdb--se--repository--repository_template)
* [`timeout`](#-graphdb--se--repository--timeout)
* [`repository_id`](#-graphdb--se--repository--repository_id)
* [`repository_label`](#-graphdb--se--repository--repository_label)
* [`default_ns`](#-graphdb--se--repository--default_ns)
* [`entity_index_size`](#-graphdb--se--repository--entity_index_size)
* [`entity_id_size`](#-graphdb--se--repository--entity_id_size)
* [`imports`](#-graphdb--se--repository--imports)
* [`ruleset`](#-graphdb--se--repository--ruleset)
* [`storage_folder`](#-graphdb--se--repository--storage_folder)
* [`enable_context_index`](#-graphdb--se--repository--enable_context_index)
* [`enable_predicate_list`](#-graphdb--se--repository--enable_predicate_list)
* [`in_memory_literal_properties`](#-graphdb--se--repository--in_memory_literal_properties)
* [`enable_literal_index`](#-graphdb--se--repository--enable_literal_index)
* [`check_for_inconsistencies`](#-graphdb--se--repository--check_for_inconsistencies)
* [`disable_same_as`](#-graphdb--se--repository--disable_same_as)
* [`transaction_mode`](#-graphdb--se--repository--transaction_mode)
* [`transaction_isolation`](#-graphdb--se--repository--transaction_isolation)
* [`query_timeout`](#-graphdb--se--repository--query_timeout)
* [`query_limit_results`](#-graphdb--se--repository--query_limit_results)
* [`throw_query_evaluation_exception_on_timeout`](#-graphdb--se--repository--throw_query_evaluation_exception_on_timeout)
* [`read_only`](#-graphdb--se--repository--read_only)

##### <a name="-graphdb--se--repository--ensure"></a>`ensure`

Data type: `Graphdb::Ensure`

Whether the service should exist. Possible values are present and absent.

Default value: `$graphdb::ensure`

##### <a name="-graphdb--se--repository--endpoint"></a>`endpoint`

Data type: `String`

GraphDB endpoint.
example: http://localhost:8080

##### <a name="-graphdb--se--repository--repository_context"></a>`repository_context`

Data type: `String`

The context of the repository.
example: http://ontotext.com

##### <a name="-graphdb--se--repository--repository_template"></a>`repository_template`

Data type: `String`

The template to use for repository creation
example: http://ontotext.com

Default value: `"${module_name}/repository/se.ttl.erb"`

##### <a name="-graphdb--se--repository--timeout"></a>`timeout`

Data type: `Integer`

The max number of seconds that the repository create/delete/check process should wait before giving up.
default: 60

Default value: `60`

##### <a name="-graphdb--se--repository--repository_id"></a>`repository_id`

Data type: `String`

Repository ID

Default value: `$title`

##### <a name="-graphdb--se--repository--repository_label"></a>`repository_label`

Data type: `String`

Repository title

Default value: `'GraphdDB SE repository'`

##### <a name="-graphdb--se--repository--default_ns"></a>`default_ns`

Data type: `String`

Default namespaces for imports(';' delimited)

Default value: `''`

##### <a name="-graphdb--se--repository--entity_index_size"></a>`entity_index_size`

Data type: `String`

Entity index size

Default value: `'200000'`

##### <a name="-graphdb--se--repository--entity_id_size"></a>`entity_id_size`

Data type: `String`

Entity ID bit-size

Default value: `'32'`

##### <a name="-graphdb--se--repository--imports"></a>`imports`

Data type: `String`

Imported RDF files(';' delimited)

Default value: `''`

##### <a name="-graphdb--se--repository--ruleset"></a>`ruleset`

Data type: `String`

Rule-set

Default value: `'owl-horst-optimized'`

##### <a name="-graphdb--se--repository--storage_folder"></a>`storage_folder`

Data type: `String`

Storage folder

Default value: `'storage'`

##### <a name="-graphdb--se--repository--enable_context_index"></a>`enable_context_index`

Data type: `Boolean`

Use context index

Default value: `false`

##### <a name="-graphdb--se--repository--enable_predicate_list"></a>`enable_predicate_list`

Data type: `Boolean`

Use predicate indices

Default value: `false`

##### <a name="-graphdb--se--repository--in_memory_literal_properties"></a>`in_memory_literal_properties`

Data type: `Boolean`

Cache literal language tags

Default value: `false`

##### <a name="-graphdb--se--repository--enable_literal_index"></a>`enable_literal_index`

Data type: `Boolean`

Enable literal index

Default value: `true`

##### <a name="-graphdb--se--repository--check_for_inconsistencies"></a>`check_for_inconsistencies`

Data type: `Boolean`

Check for inconsistencies

Default value: `false`

##### <a name="-graphdb--se--repository--disable_same_as"></a>`disable_same_as`

Data type: `Boolean`

Disable OWL sameAs optimisation

Default value: `false`

##### <a name="-graphdb--se--repository--transaction_mode"></a>`transaction_mode`

Data type: `String`

Transaction mode

Default value: `'safe'`

##### <a name="-graphdb--se--repository--transaction_isolation"></a>`transaction_isolation`

Data type: `Boolean`

Transaction isolation

Default value: `true`

##### <a name="-graphdb--se--repository--query_timeout"></a>`query_timeout`

Data type: `String`

Query time-out (seconds)

Default value: `'0'`

##### <a name="-graphdb--se--repository--query_limit_results"></a>`query_limit_results`

Data type: `String`

Limit query results

Default value: `'0'`

##### <a name="-graphdb--se--repository--throw_query_evaluation_exception_on_timeout"></a>`throw_query_evaluation_exception_on_timeout`

Data type: `Boolean`

Throw exception on query time-out

Default value: `false`

##### <a name="-graphdb--se--repository--read_only"></a>`read_only`

Data type: `Boolean`

Read-only

Default value: `false`

### <a name="graphdb--service"></a>`graphdb::service`

Based on parameters passed defines systemd service

#### Parameters

The following parameters are available in the `graphdb::service` defined type:

* [`ensure`](#-graphdb--service--ensure)
* [`status`](#-graphdb--service--status)
* [`java_opts`](#-graphdb--service--java_opts)
* [`kill_timeout`](#-graphdb--service--kill_timeout)

##### <a name="-graphdb--service--ensure"></a>`ensure`

Data type: `Graphdb::Ensure`

Whether the service should exist. Possible values are present and absent.

##### <a name="-graphdb--service--status"></a>`status`

Data type: `Graphdb::Status`

What the state of the service must be. Possible values are enabled, disabled, running and unmanaged.

##### <a name="-graphdb--service--java_opts"></a>`java_opts`

Data type: `Array`

Array of java options to give to GraphDB java process
example: ['-Xmx1g', '-Xms1g']

Default value: `[]`

##### <a name="-graphdb--service--kill_timeout"></a>`kill_timeout`

Data type: `Integer`

Time before force kill of GraphDB process. Instances with big repositories may
time to flush on shutdown.
default: 180

Default value: `180`

## Resource types

### <a name="graphdb_data"></a>`graphdb_data`

Loads data into GraphDB

#### Properties

The following properties are available in the `graphdb_data` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `graphdb_data` type.

* [`data`](#-graphdb_data--data)
* [`data_context`](#-graphdb_data--data_context)
* [`data_format`](#-graphdb_data--data_format)
* [`data_overwrite`](#-graphdb_data--data_overwrite)
* [`data_source`](#-graphdb_data--data_source)
* [`endpoint`](#-graphdb_data--endpoint)
* [`exists_expected_response`](#-graphdb_data--exists_expected_response)
* [`exists_query`](#-graphdb_data--exists_query)
* [`name`](#-graphdb_data--name)
* [`provider`](#-graphdb_data--provider)
* [`repository_id`](#-graphdb_data--repository_id)
* [`timeout`](#-graphdb_data--timeout)

##### <a name="-graphdb_data--data"></a>`data`

The data you want to load into repository
Supported formats:
String: 'data'
Array: ['data#1','data#2']
Array of Hashes: [{'content' => 'data#1', 'context' => 'context_of_data#1', 'format' => 'format_of_data1'},
{'content' => 'data#2', 'context' => 'context_of_data#2', 'format' => 'format_of_data2'}]
Mixed Array: [{'content' => 'data#1', 'context' => 'context_of_data#1', 'format' => 'format_of_data1'}, 'data#2']
note#1: if context for data not provided data_context is used
note#2: if format for data not provided data_format is used

##### <a name="-graphdb_data--data_context"></a>`data_context`

The context you want to load your data into; default: null

Default value: `null`

##### <a name="-graphdb_data--data_format"></a>`data_format`

Valid values: `Puppet::Util::DataTypeExtensions.values`

The format of the data. e.g.: turtle

##### <a name="-graphdb_data--data_overwrite"></a>`data_overwrite`

Wheather to overwrite any existing data; default: false

Default value: `false`

##### <a name="-graphdb_data--data_source"></a>`data_source`

The source of data you want to load into repository
Supported formats:
String: 'path_to_file'
String: 'path_to_directory'
Array: ['path_to_file#1','path_to_file#2']
Array of Hashes: [{'source' => 'path_to_file#1', 'context' => 'context_of_file#1', 'format' => 'format_of_file#1'},
{'source' => 'path_to_file#2', 'context' => 'context_of_file#2', 'format' => 'format_of_file#2'}]
Mixed Array: [{'source' => 'path_to_file#1', 'context' => 'context_of_file#1', 'format' => 'format_of_file#1'},
'path_to_file#2']
note#1: if context for file not provided data_context is used
note#2: if format for file not provided trying to resolve format from file if fails data_format is used

##### <a name="-graphdb_data--endpoint"></a>`endpoint`

Sesame endpoint of GraphDB instance

##### <a name="-graphdb_data--exists_expected_response"></a>`exists_expected_response`

The expected response from exists_query

Default value: `true`

##### <a name="-graphdb_data--exists_query"></a>`exists_query`

The ask query to check whether data is already loaded. You can use the following syntax: ask {?s ?p ?o}

##### <a name="-graphdb_data--name"></a>`name`

namevar

An arbitrary name used as the identity of the resource.

##### <a name="-graphdb_data--provider"></a>`provider`

The specific backend to use for this `graphdb_data` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-graphdb_data--repository_id"></a>`repository_id`

The id of the created repository

##### <a name="-graphdb_data--timeout"></a>`timeout`

The max number of seconds that the loading process should wait before giving up; default: 60 seconds

Default value: `60`

### <a name="graphdb_link"></a>`graphdb_link`

Creates link between master and worker

#### Properties

The following properties are available in the `graphdb_link` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `graphdb_link` type.

* [`master_endpoint`](#-graphdb_link--master_endpoint)
* [`master_repository_id`](#-graphdb_link--master_repository_id)
* [`name`](#-graphdb_link--name)
* [`peer_master_endpoint`](#-graphdb_link--peer_master_endpoint)
* [`peer_master_node_id`](#-graphdb_link--peer_master_node_id)
* [`peer_master_repository_id`](#-graphdb_link--peer_master_repository_id)
* [`provider`](#-graphdb_link--provider)
* [`replication_port`](#-graphdb_link--replication_port)
* [`worker_endpoint`](#-graphdb_link--worker_endpoint)
* [`worker_repository_id`](#-graphdb_link--worker_repository_id)

##### <a name="-graphdb_link--master_endpoint"></a>`master_endpoint`

Sesame endpoint of GraphDB master instance

##### <a name="-graphdb_link--master_repository_id"></a>`master_repository_id`

The id of the master repository

##### <a name="-graphdb_link--name"></a>`name`

namevar

An arbitrary name used as the identity of the resource.

##### <a name="-graphdb_link--peer_master_endpoint"></a>`peer_master_endpoint`

Sesame endpoint of GraphDB peer master instance

##### <a name="-graphdb_link--peer_master_node_id"></a>`peer_master_node_id`

The node id of peer master instance

##### <a name="-graphdb_link--peer_master_repository_id"></a>`peer_master_repository_id`

The id of the peer master repository

##### <a name="-graphdb_link--provider"></a>`provider`

The specific backend to use for this `graphdb_link` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-graphdb_link--replication_port"></a>`replication_port`

The port for replications that master and worker will use; default: 0

Default value: `0`

##### <a name="-graphdb_link--worker_endpoint"></a>`worker_endpoint`

Sesame endpoint of GraphDB worker instance

##### <a name="-graphdb_link--worker_repository_id"></a>`worker_repository_id`

The id of the worker repository

### <a name="graphdb_repository"></a>`graphdb_repository`

Creates GraphDB repository

#### Properties

The following properties are available in the `graphdb_repository` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `graphdb_repository` type.

* [`endpoint`](#-graphdb_repository--endpoint)
* [`name`](#-graphdb_repository--name)
* [`node_id`](#-graphdb_repository--node_id)
* [`provider`](#-graphdb_repository--provider)
* [`replication_port`](#-graphdb_repository--replication_port)
* [`repository_context`](#-graphdb_repository--repository_context)
* [`repository_id`](#-graphdb_repository--repository_id)
* [`repository_template`](#-graphdb_repository--repository_template)
* [`timeout`](#-graphdb_repository--timeout)

##### <a name="-graphdb_repository--endpoint"></a>`endpoint`

Sesame endpoint of GraphDB instance

##### <a name="-graphdb_repository--name"></a>`name`

namevar

An arbitrary name used as the identity of the resource.

##### <a name="-graphdb_repository--node_id"></a>`node_id`

The node id of master instance

##### <a name="-graphdb_repository--provider"></a>`provider`

The specific backend to use for this `graphdb_repository` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-graphdb_repository--replication_port"></a>`replication_port`

The replication port used for backups

##### <a name="-graphdb_repository--repository_context"></a>`repository_context`

The context of the created repository

##### <a name="-graphdb_repository--repository_id"></a>`repository_id`

The id of the created repository

##### <a name="-graphdb_repository--repository_template"></a>`repository_template`

The template of the created repository

##### <a name="-graphdb_repository--timeout"></a>`timeout`

The max number of seconds that graphdb create/delete/check process should wait before giving up
and deciding that the GraphDB is not running; default: 60 seconds.

Default value: `60`

### <a name="graphdb_update"></a>`graphdb_update`

Executes update query GraphDB

#### Properties

The following properties are available in the `graphdb_update` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `graphdb_update` type.

* [`endpoint`](#-graphdb_update--endpoint)
* [`exists_expected_response`](#-graphdb_update--exists_expected_response)
* [`exists_query`](#-graphdb_update--exists_query)
* [`name`](#-graphdb_update--name)
* [`provider`](#-graphdb_update--provider)
* [`repository_id`](#-graphdb_update--repository_id)
* [`timeout`](#-graphdb_update--timeout)
* [`update_query`](#-graphdb_update--update_query)

##### <a name="-graphdb_update--endpoint"></a>`endpoint`

Sesame endpoint of GraphDB instance

##### <a name="-graphdb_update--exists_expected_response"></a>`exists_expected_response`

The expected response from exists_query

Default value: `true`

##### <a name="-graphdb_update--exists_query"></a>`exists_query`

The ask query to check whether update has been applied. You can use the following syntax: ask {?s ?p ?o}

##### <a name="-graphdb_update--name"></a>`name`

namevar

An arbitrary name used as the identity of the resource.

##### <a name="-graphdb_update--provider"></a>`provider`

The specific backend to use for this `graphdb_update` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-graphdb_update--repository_id"></a>`repository_id`

The id of the created repository

##### <a name="-graphdb_update--timeout"></a>`timeout`

The max number of seconds that the update process should wait before giving up; default: 60 seconds.

Default value: `60`

##### <a name="-graphdb_update--update_query"></a>`update_query`

The update query you want to execute repository

### <a name="graphdb_validator"></a>`graphdb_validator`

Checks whether GraphDB instance is running

#### Properties

The following properties are available in the `graphdb_validator` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `graphdb_validator` type.

* [`endpoint`](#-graphdb_validator--endpoint)
* [`name`](#-graphdb_validator--name)
* [`provider`](#-graphdb_validator--provider)
* [`timeout`](#-graphdb_validator--timeout)

##### <a name="-graphdb_validator--endpoint"></a>`endpoint`

Sesame endpoint of GraphDB instance

##### <a name="-graphdb_validator--name"></a>`name`

namevar

An arbitrary name used as the identity of the resource.

##### <a name="-graphdb_validator--provider"></a>`provider`

The specific backend to use for this `graphdb_validator` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

##### <a name="-graphdb_validator--timeout"></a>`timeout`

The max number of seconds that the validator should wait before giving up
and deciding that the GraphDB is not running; default: 60 seconds.

Default value: `60`

## Functions

### <a name="generate_java_opts_string"></a>`generate_java_opts_string`

Type: Ruby 3.x API

This function java opts string from given array.

#### `generate_java_opts_string()`

This function java opts string from given array.

Returns: `Any`

## Data types

### <a name="Graphdb--Ensure"></a>`Graphdb::Ensure`

Validate the value of the ensure parameter for a install

Alias of `Enum['present', 'absent']`

### <a name="Graphdb--Status"></a>`Graphdb::Status`

Validate the value of the status parameter for a install

Alias of `Enum['enabled', 'disabled', 'running', 'unmanaged']`

